/*
** showip.c -- show IP addresses for a host given on the command line
*/

#include <stdio.h>
#include <string.h>
#include <sys/types.h>
#include <sys/socket.h>
//#include <proto/bsdsocket.h>
#include <netdb.h>
#include <arpa/inet.h>

#include "gai.h"

int main(int argc, char *argv[])
{
	struct addrinfo hints, *res, *p;
	int status;
	char ipstr[16];  //was INET_ADDRSTRLEN, not defined.;

	if (argc != 2) {
	    fprintf(stderr,"usage: showip hostname\n");
	    return 1;
	}

	memset(&hints, 0, sizeof hints);
	hints.ai_family = AF_INET;
	hints.ai_socktype = SOCK_STREAM;

	if ((status = getaddrinfo_gai(argv[1], NULL, &hints, &res)) != 0) {
		fprintf(stderr, "getaddrinfo: %s\n", gai_strerror_gai(status));
		return 2;
	}

	printf("IP addresses for %s:\n\n", argv[1]);

	for(p = res;p != NULL; p = p->ai_next) {
		void *addr;

		// get the pointer to the address itself,
		if (p->ai_family == AF_INET) { // IPv4
			struct sockaddr_in *ipv4 = (struct sockaddr_in *)p->ai_addr;
			addr = &(ipv4->sin_addr);
		}

		// convert the IP to a string and print it:
		inet_ntop_gai(p->ai_family, addr, ipstr, sizeof ipstr);
		printf(" IPv4: %s\n", ipstr);
	}

	freeaddrinfo_gai(res); // free the linked list

	return 0;
}
